summaryrefslogtreecommitdiff
path: root/nuttx/include/nuttx/clock.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-04-13 21:44:24 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-04-13 21:44:24 +0000
commit7cbeae30b426e0912d1814c76e6223fb0842a9fc (patch)
treea18e5e084078df356178ec94987ed828ec669f22 /nuttx/include/nuttx/clock.h
parentea4461bfe4f667a624055c6a061aaef49e33cace (diff)
downloadnuttx-7cbeae30b426e0912d1814c76e6223fb0842a9fc.tar.gz
nuttx-7cbeae30b426e0912d1814c76e6223fb0842a9fc.tar.bz2
nuttx-7cbeae30b426e0912d1814c76e6223fb0842a9fc.zip
Macro clock_systimer replaces direct access to g_system_timer variable
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@3500 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/nuttx/clock.h')
-rw-r--r--nuttx/include/nuttx/clock.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/include/nuttx/clock.h b/nuttx/include/nuttx/clock.h
index 3cd3e36f8..9a9523a2e 100644
--- a/nuttx/include/nuttx/clock.h
+++ b/nuttx/include/nuttx/clock.h
@@ -113,7 +113,7 @@
#if !defined(CONFIG_DISABLE_CLOCK) && \
(!defined(CONFIG_NUTTX_KERNEL) || defined(__KERNEL__))
extern volatile uint32_t g_system_timer;
-#define os_systime32() g_system_timer
+#define clock_systimer() g_system_timer
#endif
/****************************************************************************
@@ -132,12 +132,12 @@ extern "C" {
#endif
/* If direct access to the system timer/counter is not supported (see above),
* then the value can be obtained via os_systime32 through a system call.
*/
#if !defined(CONFIG_DISABLE_CLOCK) && \
defined(CONFIG_NUTTX_KERNEL) && !defined(__KERNEL__)
-EXTERN uint32_t os_systime32(void);
+EXTERN uint32_t clock_systimer(void);
#endif
#undef EXTERN
@@ -132,12 +132,12 @@ extern "C" {
#endif
/* If direct access to the system timer/counter is not supported (see above),
- * then the value can be obtained via os_systime32 through a system call.
+ * then the value can be obtained via clock_systimer through a system call.
*/
#if !defined(CONFIG_DISABLE_CLOCK) && \